# coding: utf-8

"""
    Radarr

    Radarr API docs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel

class IndexerConfigResource(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    id: Optional[int]
    minimum_age: Optional[int]
    maximum_size: Optional[int]
    retention: Optional[int]
    rss_sync_interval: Optional[int]
    prefer_indexer_flags: Optional[bool]
    availability_delay: Optional[int]
    allow_hardcoded_subs: Optional[bool]
    whitelisted_hardcoded_subs: Optional[str]
    __properties = ["id", "minimumAge", "maximumSize", "retention", "rssSyncInterval", "preferIndexerFlags", "availabilityDelay", "allowHardcodedSubs", "whitelistedHardcodedSubs"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        alias_generator = lambda x: x.split("_")[0] + "".join(word.capitalize() for word in x.split("_")[1:])

    def __getitem__(self, item):
        return getattr(self, item)

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> IndexerConfigResource:
        """Create an instance of IndexerConfigResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if whitelisted_hardcoded_subs (nullable) is None
        if self.whitelisted_hardcoded_subs is None:
            _dict['whitelistedHardcodedSubs'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> IndexerConfigResource:
        """Create an instance of IndexerConfigResource from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return IndexerConfigResource.parse_obj(obj)

        _obj = IndexerConfigResource.parse_obj({
            "id": obj.get("id"),
            "minimum_age": obj.get("minimumAge"),
            "maximum_size": obj.get("maximumSize"),
            "retention": obj.get("retention"),
            "rss_sync_interval": obj.get("rssSyncInterval"),
            "prefer_indexer_flags": obj.get("preferIndexerFlags"),
            "availability_delay": obj.get("availabilityDelay"),
            "allow_hardcoded_subs": obj.get("allowHardcodedSubs"),
            "whitelisted_hardcoded_subs": obj.get("whitelistedHardcodedSubs")
        })
        return _obj

